==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/General/rdetect/translations/rdetect_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Ajouter CD « %1 »</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Ajouter volume « %1 »</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Détection de CD audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Ajouter automatiquement les pistes à la liste</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Enlever automatiquement les pistes de la liste</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Détection de périphérique amovible</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Ajouter automatiquement les fichiers à la liste</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Enlever automatiquement les fichiers à la liste</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/General/rdetect/translations/rdetect_plugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>RDetectFactory</name>
    <message>
        <location filename="../rdetectfactory.cpp" line="30"/>
        <source>Volume Detection Plugin</source>
        <translation>Greffon de détection du volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="50"/>
        <source>About Volume Detection Plugin</source>
        <translation>À propos du greffon de détection du volume</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="51"/>
        <source>Qmmp Removable Volume Detection Plugin</source>
        <translation>Greffon de détection des volumes amovibles</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="52"/>
        <source>This plugin provides removable volume detection</source>
        <translation>Ce greffon permet la détection des volumes amovibles</translation>
    </message>
    <message>
        <location filename="../rdetectfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>RDetectSettingsDialog</name>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="14"/>
        <source>Volume Detection Plugin Settings</source>
        <translation>Paramètres du greffon de détection du volume</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Détection de CD audio</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Ajouter automatiquement les pistes à la liste</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Enlever automatiquement les pistes de la liste</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Détection de périphérique amovible</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Ajouter automatiquement les fichiers à la liste</translation>
    </message>
    <message>
        <location filename="../rdetectsettingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Enlever automatiquement les fichiers à la liste</translation>
    </message>
</context>
<context>
    <name>RemovableHelper</name>
    <message>
        <location filename="../removablehelper.cpp" line="134"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>Ajouter CD «&#xa0;%1&#xa0;»</translation>
    </message>
    <message>
        <location filename="../removablehelper.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Ajouter volume «&#xa0;%1&#xa0;»</translation>
    </message>
</context>
</TS>
